@@ -76,6 +76,7 @@
 #include "PieceSelector.h"
 #include "a2functional.h"
 #include "SocketCore.h"
+#include "SimpleRandomizer.h"
 #ifdef ENABLE_MESSAGE_DIGEST
 # include "CheckIntegrityCommand.h"
 #endif // ENABLE_MESSAGE_DIGEST
@@ -100,6 +101,7 @@
 # include "DHTPeerAnnounceStorage.h"
 # include "DHTEntryPointNameResolveCommand.h"
 # include "LongestSequencePieceSelector.h"
+# include "PriorityPieceSelector.h"
 #endif // ENABLE_BITTORRENT
 #ifdef ENABLE_METALINK
 # include "MetalinkPostDownloadHandler.h"
@@ -196,14 +198,15 @@ void RequestGroup::closeFile()
   }
 }
 
-void RequestGroup::createInitialCommand(std::deque<Command*>& commands,
-					DownloadEngine* e)
+void RequestGroup::createInitialCommand
+(std::deque<Command*>& commands, DownloadEngine* e)
 {
 #ifdef ENABLE_BITTORRENT
   {
     if(_downloadContext->hasAttribute(bittorrent::BITTORRENT)) {
       const BDE& torrentAttrs =
 	_downloadContext->getAttribute(bittorrent::BITTORRENT);
+      bool metadataGetMode = !torrentAttrs.containsKey(bittorrent::METADATA);
       if(_option->getAsBool(PREF_DRY_RUN)) {
 	throw DOWNLOAD_FAILURE_EXCEPTION
 	  ("Cancel BitTorrent download in dry-run context.");
@@ -214,35 +217,45 @@ void RequestGroup::createInitialCommand(std::deque<Command*>& commands,
 	throw DOWNLOAD_FAILURE_EXCEPTION
 	  (StringFormat
 	   ("InfoHash %s is already registered.",
-	    util::toHex(torrentAttrs[bittorrent::INFO_HASH].s()).c_str()).str());
+	    bittorrent::getInfoHashString(_downloadContext).c_str()).str());
       }
-
-      if(e->_requestGroupMan->isSameFileBeingDownloaded(this)) {
-	throw DOWNLOAD_FAILURE_EXCEPTION
-	  (StringFormat(EX_DUPLICATE_FILE_DOWNLOAD,
-			_downloadContext->getBasePath().c_str()).str());
-      }
-      initPieceStorage();
-      if(_downloadContext->getFileEntries().size() > 1) {
-	_pieceStorage->setupFileFilter();
+      if(metadataGetMode) {
+	// Use UnknownLengthPieceStorage.
+	initPieceStorage();
+      } else {
+	if(e->_requestGroupMan->isSameFileBeingDownloaded(this)) {
+	  throw DOWNLOAD_FAILURE_EXCEPTION
+	    (StringFormat(EX_DUPLICATE_FILE_DOWNLOAD,
+			  _downloadContext->getBasePath().c_str()).str());
+	}
+	initPieceStorage();
+	if(_downloadContext->getFileEntries().size() > 1) {
+	  _pieceStorage->setupFileFilter();
+	}
       }
       
-      SharedHandle<DefaultBtProgressInfoFile>
-	progressInfoFile(new DefaultBtProgressInfoFile(_downloadContext,
-						       _pieceStorage,
-						       _option.get()));
+      SharedHandle<DefaultBtProgressInfoFile> progressInfoFile;
+      if(!metadataGetMode) {
+	progressInfoFile.reset(new DefaultBtProgressInfoFile(_downloadContext,
+							     _pieceStorage,
+							     _option.get()));
+      }
         
       BtRuntimeHandle btRuntime(new BtRuntime());
       btRuntime->setMaxPeers(_option->getAsInt(PREF_BT_MAX_PEERS));
       _btRuntime = btRuntime;
-      progressInfoFile->setBtRuntime(btRuntime);
+      if(!progressInfoFile.isNull()) {
+	progressInfoFile->setBtRuntime(btRuntime);
+      }
 
       SharedHandle<DefaultPeerStorage> peerStorage
 	(new DefaultPeerStorage(_option.get()));
       peerStorage->setBtRuntime(btRuntime);
       peerStorage->setPieceStorage(_pieceStorage);
       _peerStorage = peerStorage;
-      progressInfoFile->setPeerStorage(peerStorage);
+      if(!progressInfoFile.isNull()) {
+	progressInfoFile->setPeerStorage(peerStorage);
+      }
 
       SharedHandle<DefaultBtAnnounce> btAnnounce
 	(new DefaultBtAnnounce(_downloadContext, _option.get()));
@@ -253,13 +266,32 @@ void RequestGroup::createInitialCommand(std::deque<Command*>& commands,
 	(_option->getAsInt(PREF_BT_TRACKER_INTERVAL));
       btAnnounce->shuffleAnnounce();
       
-      btRegistry->put(torrentAttrs[bittorrent::INFO_HASH].s(),
+      btRegistry->put(_gid,
 		      BtObject(_downloadContext,
 			       _pieceStorage,
 			       peerStorage,
 			       btAnnounce,
 			       btRuntime,
-			       progressInfoFile));
+			       (progressInfoFile.isNull()?
+				_progressInfoFile:
+				SharedHandle<BtProgressInfoFile>
+				(progressInfoFile))));
+      if(metadataGetMode) {
+	if(_option->getAsBool(PREF_ENABLE_DHT)) {
+	  std::deque<Command*> dhtCommands;
+	  DHTSetup().setup(dhtCommands, e, _option.get());
+	  e->addCommand(dhtCommands);
+	} else {
+	  _logger->notice("For BitTorrent Magnet URI, enabling DHT is strongly"
+			  " recommended. See --enable-dht option.");
+	}
+
+	SharedHandle<CheckIntegrityEntry> entry
+	  (new BtCheckIntegrityEntry(this));
+	entry->onDownloadIncomplete(commands, e);
+	
+	return;
+      }
 
       // Remove the control file if download file doesn't exist
       if(progressInfoFile->exists() && !_pieceStorage->getDiskAdaptor()->fileExists()) {
@@ -415,15 +447,32 @@ void RequestGroup::initPieceStorage()
 #ifdef ENABLE_BITTORRENT
     SharedHandle<DefaultPieceStorage> ps
       (new DefaultPieceStorage(_downloadContext, _option.get()));
-    // Use LongestSequencePieceSelector when HTTP/FTP/BitTorrent integrated
-    // downloads. Currently multi-file integrated download is not supported.
-    if(_downloadContext->hasAttribute(bittorrent::BITTORRENT) &&
-       isUriSuppliedForRequsetFileEntry
-       (_downloadContext->getFileEntries().begin(),
-	_downloadContext->getFileEntries().end())) {
-      _logger->debug("Using LongestSequencePieceSelector");
-      ps->setPieceSelector
-	(SharedHandle<PieceSelector>(new LongestSequencePieceSelector()));
+    if(_downloadContext->hasAttribute(bittorrent::BITTORRENT)) {
+      if(isUriSuppliedForRequsetFileEntry
+	 (_downloadContext->getFileEntries().begin(),
+	  _downloadContext->getFileEntries().end())) {
+	// Use LongestSequencePieceSelector when HTTP/FTP/BitTorrent
+	// integrated downloads. Currently multi-file integrated
+	// download is not supported.
+	_logger->debug("Using LongestSequencePieceSelector");
+	ps->setPieceSelector
+	  (SharedHandle<PieceSelector>(new LongestSequencePieceSelector()));
+      }
+      if(_option->defined(PREF_BT_PRIORITIZE_PIECE)) {
+	std::vector<size_t> result;
+	util::parsePrioritizePieceRange
+	  (result, _option->get(PREF_BT_PRIORITIZE_PIECE),
+	   _downloadContext->getFileEntries(),
+	   _downloadContext->getPieceLength());
+	if(!result.empty()) {
+	  std::random_shuffle(result.begin(), result.end(),
+			      *(SimpleRandomizer::getInstance().get()));
+	  SharedHandle<PriorityPieceSelector> priSelector
+	    (new PriorityPieceSelector(ps->getPieceSelector()));
+	  priSelector->setPriorityPiece(result.begin(), result.end());
+	  ps->setPieceSelector(priSelector);
+	}
+      }
     }
 #else // !ENABLE_BITTORRENT
     SharedHandle<DefaultPieceStorage> ps
@@ -748,24 +797,7 @@ void RequestGroup::setForceHaltRequested(bool f, HaltReason haltReason)
 void RequestGroup::releaseRuntimeResource(DownloadEngine* e)
 {
 #ifdef ENABLE_BITTORRENT
-  if(_downloadContext->hasAttribute(bittorrent::BITTORRENT)) {
-    SharedHandle<BtRegistry> btRegistry = e->getBtRegistry();
-    const BDE& torrentAttrs =
-      _downloadContext->getAttribute(bittorrent::BITTORRENT);
-    const std::string& infoHash = torrentAttrs[bittorrent::INFO_HASH].s();
-    SharedHandle<DownloadContext> contextInReg =
-      btRegistry->getDownloadContext(infoHash);
-    // Make sure that the registered DownloadContext's GID is equal to
-    // _gid.  Even if createInitialCommand() throws exception without
-    // registering this DownloadContext, after that, this method is
-    // called. In this case, just finding DownloadContext using
-    // infoHash may detect another download's DownloadContext and
-    // deleting it from BtRegistry causes Segmentation Fault.
-    if(!contextInReg.isNull() &&
-       contextInReg->getOwnerRequestGroup()->getGID() == _gid) {
-      btRegistry->remove(infoHash);
-    }
-  }
+  e->getBtRegistry()->remove(_gid);
 #endif // ENABLE_BITTORRENT
   if(!_pieceStorage.isNull()) {
     _pieceStorage->removeAdvertisedPiece(0);
@@ -875,12 +907,12 @@ void RequestGroup::addPreDownloadHandler(const PreDownloadHandlerHandle& handler
   _preDownloadHandlers.push_back(handler);
 }
 
-void RequestGroup::clearPostDowloadHandler()
+void RequestGroup::clearPostDownloadHandler()
 {
   _postDownloadHandlers.clear();
 }
 
-void RequestGroup::clearPreDowloadHandler()
+void RequestGroup::clearPreDownloadHandler()
 {
   _preDownloadHandlers.clear();
 }
@@ -934,11 +966,15 @@ void RequestGroup::reportDownloadFinished()
 #ifdef ENABLE_BITTORRENT
   if(_downloadContext->hasAttribute(bittorrent::BITTORRENT)) {
     TransferStat stat = calculateStat();
-    double shareRatio = ((stat.getAllTimeUploadLength()*10)/getCompletedLength())/10.0;
-    _logger->notice(MSG_SHARE_RATIO_REPORT,
-		    shareRatio,
-		    util::abbrevSize(stat.getAllTimeUploadLength()).c_str(),
-		    util::abbrevSize(getCompletedLength()).c_str());
+    double shareRatio =
+      ((stat.getAllTimeUploadLength()*10)/getCompletedLength())/10.0;
+    const BDE& attrs = _downloadContext->getAttribute(bittorrent::BITTORRENT);
+    if(attrs.containsKey(bittorrent::METADATA)) {
+      _logger->notice(MSG_SHARE_RATIO_REPORT,
+		      shareRatio,
+		      util::abbrevSize(stat.getAllTimeUploadLength()).c_str(),
+		      util::abbrevSize(getCompletedLength()).c_str());
+    }
   }
 #endif // ENABLE_BITTORRENT
 }
@@ -1033,4 +1069,13 @@ void RequestGroup::removeControlFile() const
   _progressInfoFile->removeFile();
 }
 
+void RequestGroup::setDownloadContext
+(const SharedHandle<DownloadContext>& downloadContext)
+{
+  _downloadContext = downloadContext;
+  if(!_downloadContext.isNull()) {
+    _downloadContext->setOwnerRequestGroup(this);
+  }
+}
+
 } // namespace aria2
