@@ -56,13 +56,16 @@
 #include "FileEntry.h"
 #include "LogFactory.h"
 #include "File.h"
-#include "Util.h"
+#include "util.h"
 #include "array_fun.h"
 #include "OptionHandler.h"
 #include "ByteArrayDiskWriter.h"
 #include "a2functional.h"
+#include "ByteArrayDiskWriterFactory.h"
 #ifdef ENABLE_BITTORRENT
 # include "bittorrent_helper.h"
+# include "BtConstants.h"
+# include "UTMetadataPostDownloadHandler.h"
 #endif // ENABLE_BITTORRENT
 
 namespace aria2 {
@@ -109,6 +112,7 @@ const std::set<std::string>& listRequestOptions()
     PREF_BT_MAX_OPEN_FILES,
     PREF_BT_MAX_PEERS,
     PREF_BT_MIN_CRYPTO_LEVEL,
+    PREF_BT_PRIORITIZE_PIECE,
     PREF_BT_REQUIRE_CRYPTO,
     PREF_BT_REQUEST_PEER_SPEED_LIMIT,
     PREF_BT_SEED_UNVERIFIED,
@@ -210,17 +214,44 @@ createBtRequestGroup(const std::string& torrentFilePath,
     // throw
     // exception
   }
-  dctx->setFileFilter(Util::parseIntRange(option->get(PREF_SELECT_FILE)));
+  dctx->setFileFilter(util::parseIntRange(option->get(PREF_SELECT_FILE)));
   std::istringstream indexOutIn(option->get(PREF_INDEX_OUT));
   std::map<size_t, std::string> indexPathMap =
-    Util::createIndexPathMap(indexOutIn);
+    util::createIndexPathMap(indexOutIn);
   for(std::map<size_t, std::string>::const_iterator i = indexPathMap.begin();
       i != indexPathMap.end(); ++i) {
     dctx->setFilePathWithIndex
       ((*i).first, strconcat(dctx->getDir(), "/", (*i).second));
   }
   rg->setDownloadContext(dctx);
-  dctx->setOwnerRequestGroup(rg.get());
+  return rg;
+}
+
+static
+SharedHandle<RequestGroup>
+createBtMagnetRequestGroup(const std::string& magnetLink,
+			   const SharedHandle<Option>& option,
+			   const std::deque<std::string>& auxUris)
+{
+  SharedHandle<RequestGroup> rg(new RequestGroup(option));
+  SharedHandle<DownloadContext> dctx
+    (new DownloadContext(METADATA_PIECE_SIZE, 0,
+			 A2STR::NIL));
+  dctx->setDir(A2STR::NIL);
+  // We only know info hash. Total Length is unknown at this moment.
+  dctx->markTotalLengthIsUnknown();
+  rg->setFileAllocationEnabled(false);
+  rg->setPreLocalFileCheckEnabled(false);
+  bittorrent::loadMagnet(magnetLink, dctx);
+  dctx->getFirstFileEntry()->setPath
+    (dctx->getAttribute(bittorrent::BITTORRENT)[bittorrent::NAME].s());
+  rg->setDownloadContext(dctx);
+  rg->clearPostDownloadHandler();
+  rg->addPostDownloadHandler
+    (SharedHandle<UTMetadataPostDownloadHandler>
+     (new UTMetadataPostDownloadHandler()));
+  rg->setDiskWriterFactory
+    (SharedHandle<DiskWriterFactory>(new ByteArrayDiskWriterFactory()));
   return rg;
 }
 
@@ -275,10 +306,13 @@ private:
   std::deque<SharedHandle<RequestGroup> >& _requestGroups;
   ProtocolDetector _detector;
   SharedHandle<Option> _option;
+  bool _ignoreLocalPath;
 public:
   AccRequestGroup(std::deque<SharedHandle<RequestGroup> >& requestGroups,
-		  const SharedHandle<Option>& option):
-    _requestGroups(requestGroups), _option(option) {}
+		  const SharedHandle<Option>& option,
+		  bool ignoreLocalPath = false):
+    _requestGroups(requestGroups), _option(option),
+    _ignoreLocalPath(ignoreLocalPath) {}
 
   void
   operator()(const std::string& uri)
@@ -295,7 +329,17 @@ public:
       _requestGroups.push_back(rg);
     }
 #ifdef ENABLE_BITTORRENT
-    else if(_detector.guessTorrentFile(uri)) {
+    else if(_detector.guessTorrentMagnet(uri)) {
+      try {
+	SharedHandle<RequestGroup> group =
+	  createBtMagnetRequestGroup(uri, _option, std::deque<std::string>());
+	_requestGroups.push_back(group);
+      } catch(RecoverableException& e) {
+	// error occurred while parsing torrent file.
+	// We simply ignore it.	
+	LogFactory::getInstance()->error(EX_EXCEPTION_CAUGHT, e);
+      }
+    } else if(!_ignoreLocalPath && _detector.guessTorrentFile(uri)) {
       try {
 	_requestGroups.push_back(createBtRequestGroup(uri, _option,
 						      std::deque<std::string>()));
@@ -304,10 +348,10 @@ public:
 	// We simply ignore it.	
 	LogFactory::getInstance()->error(EX_EXCEPTION_CAUGHT, e);
       }
-    }
+    } 
 #endif // ENABLE_BITTORRENT
 #ifdef ENABLE_METALINK
-    else if(_detector.guessMetalinkFile(uri)) {
+    else if(!_ignoreLocalPath && _detector.guessMetalinkFile(uri)) {
       try {
 	Metalink2RequestGroup().generate(_requestGroups, uri, _option);
       } catch(RecoverableException& e) {
@@ -337,7 +381,7 @@ void createRequestGroupForUri
  const SharedHandle<Option>& option,
  const std::deque<std::string>& uris,
  bool ignoreForceSequential,
- bool ignoreNonURI)
+ bool ignoreLocalPath)
 {
   std::deque<std::string> nargs;
   if(option->get(PREF_PARAMETERIZED_URI) == V_TRUE) {
@@ -347,7 +391,7 @@ void createRequestGroupForUri
   }
   if(!ignoreForceSequential && option->get(PREF_FORCE_SEQUENTIAL) == V_TRUE) {
     std::for_each(nargs.begin(), nargs.end(),
-		  AccRequestGroup(result, option));
+		  AccRequestGroup(result, option, ignoreLocalPath));
   } else {
     std::deque<std::string>::iterator strmProtoEnd =
       std::stable_partition(nargs.begin(), nargs.end(), StreamProtocolFilter());
@@ -362,11 +406,9 @@ void createRequestGroupForUri
       rg->setNumConcurrentCommand(numSplit);
       result.push_back(rg);
     }
-    if(!ignoreNonURI) {
-      // process remaining URIs(local metalink, BitTorrent files)
-      std::for_each(strmProtoEnd, nargs.end(),
-		    AccRequestGroup(result, option));
-    }
+    // process remaining URIs(local metalink, BitTorrent files)
+    std::for_each(strmProtoEnd, nargs.end(),
+		  AccRequestGroup(result, option, ignoreLocalPath));
   }
 }
 
